import React, { Component } from 'react';
import {Footer, Header, Main, Slider, Loading} from '../src/components';
import {QRScan, Language, CheckinDocument, CheckinSelf, Location, ContactSearch, Alert, Sites, Entry } from '../src/components';
import AppStore from "./stores/AppStore";
import DesignStore from "./stores/DesignStore";
import ls from 'local-storage'

class App extends Component {
  constructor(props) {
    super(props);

    window.globals = [];
    window.globals["home"] = function(){
      window.location.reload();
    }

    this.state = {
      display: AppStore.getDisplay(),
      action: AppStore.getAction(),
      designs: DesignStore.getDesign()
    };
    this.changeAction = this.changeAction.bind(this);
    this.update = this.update.bind(this);

    window.globals["resetTimer"] = null;
    window.globals["resetTimer_reset"] = this.reset;
    window.globals["resetTimer_time"] = 0;
   }

   reset(){
       var t = window.globals["resetTimer_time"];
       if(t > 0){
         clearTimeout(window.globals["resetTimer"]);
         window.globals["resetTimer"] = setTimeout(function(){
           ls.clear();
           window.location.reload();
         }, 1000 * t);
     }
   }

   findLink(e, deep){
     let link = window.$(e).parent().data("link");
      if(deep > 100){
          return "";
      }

      if(link !== undefined){
        return link;
      }else{
        deep = deep + 1
        return this.findLink(window.$(e).parent(), deep);
      }
   }

  eventHandler(e){

    let link = e.target.getAttribute('data-link');

    if(link === null){
      link = this.findLink(e.target, 1);
    }

    this.setState({
      action: link
    });
  }

  componentDidMount (){
    DesignStore.on("design_loaded", this.update);
    AppStore.on("change_action", this.changeAction);

    window.$(document).on("keydown", "*", function() {
      console.log("reset");
      this.reset();
     }.bind(this));

    window.$(document).on("click", "*", function() {
      console.log("reset");
       this.reset();
     }.bind(this));

     window.$("<link/>", {
       rel: "stylesheet",
       href: DesignStore.getStyles()
     }).appendTo("head");
  }

  changeAction(){
    this.setState({
      action : AppStore.getAction()
    })
  }

  update(){
    this.setState({
      display : AppStore.getDisplay(),
      designs : DesignStore.getDesign()
    })

    window.globals["resetTimer_time"]  =  this.state.designs["timer"] * 1
  }

  render() {

    if(this.state.designs === null || this.state.designs === undefined){
        return(<Loading />);
    }

    let topStyles = null
    let footerStyles = null
    let mainStyles = null
    let action = this.state.action;

    if(this.state.designs){
      if(action === "" ||action === undefined){
        action = this.state.designs["start_page"];
        console.log(this.state.designs)
        console.log("going for " + this.state.designs["start_page"]);
      }
      mainStyles = {
        backgroundColor: this.state.designs["main_bg_color"],
      };
      topStyles = {
        backgroundColor: this.state.designs["top_bg_color"],
      };
      footerStyles = {
        backgroundColor: this.state.designs["bot_bg_color"],
      };
    }

    let displayAction ="";
    var show_slider = false;

    if(this.state.designs){
      if(this.state.designs["show_slider"] && this.state.designs["show_slider"] === "on"){
        show_slider = true;
      }
    }

    let invis = "invis";

    if(this.state.designs["slider_always_on"] === "on"){
      invis = "";
    }

console.log(action);

    switch (action) {
      case "QRScan":  displayAction = <QRScan />;
      break;
      case "Language":  displayAction = <Language />;
      break;
      case "CheckinDocument":  displayAction = <CheckinDocument />;
      break;
      case "CheckinSelf":  displayAction = <CheckinSelf />;
      break;
      case "Location":  displayAction = <Location />;
      break;
      case "ContactSearch":  displayAction = <ContactSearch />;
      break;
      case "Alert":  displayAction = <Alert />;
      break;
      case "Sites":  displayAction = <Sites />;
      break;
      case "entry":  displayAction = <Entry />;
      break;
      case "Main":  displayAction = <Alert />;
      default :
        displayAction = <Main handler={this.eventHandler.bind(this)} />;
        invis = "";
      break;
    }

    return (
      <div className="App" style={mainStyles}>
        <div className="row" id="header" style={topStyles}>
          <div className="col" >
            <Header  />
          </div>
        </div>
        { show_slider &&
          <div className={invis + " row"} id="slider">
            <div className="col" >
              <Slider />
            </div>
          </div>
        }
        {displayAction}
        <div className="row" id="footer" style={footerStyles} >
            <Footer display={this.state.display} />
        </div>

      </div>
    );
  }
}

export default App;
