import React from 'react';
import HostStore from "../../../stores/HostStore";
import DesignStore from "./../../../stores/DesignStore";
import * as SIP from 'sip.js'
import ContactDetail from "./ContactDetail";
import LanguageStore from "./../../../stores/LanguageStore";
import axios from 'axios';
import { properties } from '../../../properties.js';
import MSButton from "./../../UI/MSButton";

class ContactSearch extends React.Component {

  constructor(props){
    super(props)
    this.state ={
      callstatus :"nocall",
      hosts: HostStore.loadHosts(),
      designs : DesignStore.getDesign(),
      selection: null
    }
    this.sip = null;
    this.updateHosts = this.updateHosts.bind(this);
    this.listHosts = this.listHosts.bind(this);
    this.listVips = this.listVips.bind(this);
    this.selectHost = this.selectHost.bind(this);
    this.call = this.call.bind(this);
    this.endcall = this.endcall.bind(this);
    this.closeDetail = this.closeDetail.bind(this);
  }

  selectHost(e, host){
    this.setState({
      selection : host
    });
  }

  componentDidMount (){
    DesignStore.on("design_loaded", this.update);
    HostStore.on("hosts_loaded", this.updateHosts);
  }

  listVips(){
    return(
      <div className="vips main_view" id="vips">
          { this.state.hosts.map(function(host, index){
            if(host.pe_vip == "1"){
              let styles =[];
              if(this.state.designs){
                styles = {
                  backgroundColor: this.state.designs["main_color"],
                  color: "#fff"
                };
              }

              let name ="";
              let seperator ="";
              if( host.pe_name !== null && host.pe_name !== ""  && host.pe_name !== undefined ){
                name += host.pe_name;
                seperator =", ";
              }
              if( host.pe_vorname !== null && host.pe_vorname !== ""  && host.pe_vorname !== undefined ){
                name += seperator + host.pe_vorname;
              }

              return(
                <div id={host.pe_id} style={styles} onClick={(e) => this.selectHost(e, host)} className="singleHost single_vip" key={ index } >
                  <span  className="host_infos" >{name}</span>
                </div>
              );

            }
          }.bind(this)) }
      </div>
    )
  }

  update(){
    this.setState({
      designs : DesignStore.getDesign()
    })
  }

  updateHosts(){
    this.setState({
      hosts : HostStore.getHosts()
    })
  }

  closeDetail(){
    this.setState({
      selection : null
    })
  }

  listHosts(){
    return(
      <div className="main_view" id="contact_list">
          { this.state.hosts.map(function(host, index){
            if(host.pe_vip != "1"){
              let styles =[];
              if(this.state.designs){
                styles = {
                  backgroundColor: this.state.designs["main_color"],
                  color: "#fff"
                };
              }
              let name ="";
              let seperator ="";
              if( host.pe_name !== null && host.pe_name !== ""  && host.pe_name !== undefined ){
                name += host.pe_name;
                seperator =", ";
              }
              if( host.pe_vorname !== null && host.pe_vorname !== ""  && host.pe_vorname !== undefined ){
                name += seperator + host.pe_vorname;
              }

              return(
                <div id={host.pe_id} onClick={(e) => this.selectHost(e, host)} className="singleHost" style={styles} key={ index } >
                  <span  className="host_infos" >{name}</span>
                </div>
              );
            }
          }.bind(this)) }
          <div class="forward" >&#8681;</div>
      </div>
    )
  }

  call(){

    axios.get("/customportals/startcall.php?SID=" +
      properties.key + "&number=" + encodeURI(this.state.selection.pe_tel_1))
      .then(res => {
        this.setState({
          callstatus:"calling"
        });
      })

  }

  endcall(){
    axios.get("/customportals/endcall.php?SID=" +
      properties.key + "&number=" + encodeURI(this.state.selection.pe_tel_1))
      .then(res => {
        this.setState({
          callstatus:"nocall"
        });
        window.location.reload()
      })

  }

  showDetails(){
    if(this.state.selection){

      window.$(".pe_is_active").removeClass("pe_is_active");
      window.$("#" + this.state.selection.pe_id ).addClass("pe_is_active");

      return(

        <div id="details" >
          <button type="button" id="closeBtn" className="btn btn-default" onClick={this.closeDetail}>Schließen X</button>

          {this.state.selection.pe_name !== ""  &&
            <div id="detail_lastname" className="info">{LanguageStore.translate("lastname")}: {this.state.selection.pe_name}</div>
          }
          {this.state.selection.pe_vorname !== ""  &&
            <div id="detail_firstname" className="info">{LanguageStore.translate("firstname")}: {this.state.selection.pe_vorname}</div>
          }
          {this.state.selection.pe_department !== ""  &&
            <div id="detail_division" className="info">{LanguageStore.translate("division")}: {this.state.selection.pe_department}</div>
          }
          {this.state.selection.pe_room_nr !== ""  &&
            <div id="detail_room" className="info">{LanguageStore.translate("room")}: {this.state.selection.pe_room_nr}</div>
          }
          {this.state.selection.pe_floor !== ""  &&
            <div id="detail_floor" className="info">{LanguageStore.translate("floor")}: {this.state.selection.pe_floor}</div>
          }
          {this.state.selection.pe_building !== ""  &&
            <div id="detail_building"  className="info">{LanguageStore.translate("building")}: {this.state.selection.pe_building} / {this.state.selection.pe_building_part}</div>
          }

          {this.state.selection.pe_tel_1 && this.state.callstatus === "nocall"  &&
            <div className="info" id="info_call_control">
              <button className="btn btn-default" id="call_btn" onClick={this.call} >{LanguageStore.translate("call")}</button>
            </div>
          }

          {this.state.selection.pe_tel_1 && this.state.callstatus === "calling"  &&
            <div className="info">
              <button className="btn btn-default" id="call_end_btn" onClick={this.endcall} >{LanguageStore.translate("call_end")}</button>
            </div>
          }
        </div>

      );
    }else{
      return(<div />);
    }
  }

  render() {
    let content = <div>Loading ... </div>;
    let vips = "";
    let details ="";

    if(this.state.hosts !== null && this.state.hosts !== undefined ){
      content = this.listHosts();
      details = this.showDetails();
      vips = this.listVips();
    }

    return (
      <div id="ContactSearch" className="main_view">
        <h1>{LanguageStore.translate("contacts")}</h1>
        <div class="contact_wrapper">
          {vips}
          {content}
        </div>
        {details}
      </div>
    );
  }
}

export default ContactSearch;
