import React from 'react';
import CheckinStore from "./../../../stores/CheckinStore";
import LanguageStore from "./../../../stores/LanguageStore";
import Sig from "./Sig"
import MSButton from "./../../UI/MSButton"

class Checklist extends React.Component {

  constructor(props){
    super(props)
    this.state ={
      ap : props.checkin.ap,
      au : props.checkin.au,
      checkin : props.checkin,
      missing: [],
      checklist :  {}
    }

    this.sig_visitor = null;
    this.sig_host = null;

    CheckinStore.loadCheckInlist(this.state.ap.ap_checklist);
    this.update =  this.update.bind(this)
    this.submit = this.submit.bind(this);

    this.textChanged = this.textChanged.bind(this);
    this.onChange = this.onChange.bind(this);
    this.sigDone = this.sigDone.bind(this);
  }

  componentDidMount (){
    CheckinStore.on("checkInList_loaded", this.update);
  }

  update(){
    this.setState({
      checklist : CheckinStore.getCheckInlist()
    })
  }

  onChange(e, item){
    this.state.checklist.items.map(function(cp, index){
      if(cp.cp_id === item.cp_id){
        this.state.checklist.items[index].cp_val = e.target.checked;
      }
    }.bind(this))
  }

  textChanged(e , item){
    this.state.checklist.items.map(function(cp, index){
      if(cp.cp_id === item.cp_id){
        this.state.checklist.items[index].cp_val =e.target.value;
      }
    }.bind(this))
  }

  submit(event) {
    event.preventDefault();
    this.finish()
  }

  finish(){
    let failed = false;
    let cps = {};
    let miss = [];

    window.$("*").removeClass("missing");
    this.state.checklist.items.map(function(cp, index){
      if(cp.cp_required === "hard"){
        if(cp.cp_val !== true){
          failed = true;
          window.$("#li_cp_" + cp.cp_id).addClass("missing");
        }else{
          cps[cp.cp_id] = {"reason" : cp.cp_val }
        }
      } else if(cp.cp_required === "soft"){
        if(cp.cp_val === "" || cp.cp_val === false ){
          failed = true;
          window.$("#li_cp_" + cp.cp_id).addClass("missing");
        }else{
          cps[cp.cp_id] = cp.cp_id;
        }
      }else{
        cps[cp.cp_id] = cp.cp_id;
      }

    });
    if(failed){
      console.log(failed)
      this.setState({
        missing : miss
      });
      return false;
    }

    if(this.state.checklist.c_need_verify_via_sign === "1" && this.sig_visitor == null){
      this.setState({
        sig_visitor_needed: true
      })

      return;
    }

    if(this.sig_visitor !== null){
      cps["sig_data"] = {"sig_file" : this.sig_visitor.internal};
    }

    var data = {
      "ap_id" : this.state.ap.ap_id,
      "au_id" : this.state.au.au_id,
      "c_id" : this.state.checklist.c_id,
      "CP"  : cps
    }

    CheckinStore.sendCheckList(data);
  }

  sigDone(sig){
    this.sig_visitor = sig;
    this.finish();
  }

  render() {
    if(this.state.sig_visitor_needed){
        return (<Sig from="host" au={this.state.au} action={this.sigDone} />)
    }

    let items = [];
    if(this.state.checklist.items){
      items = this.state.checklist.items
    }

    return (
      <div id="check_list">
        <h1>{LanguageStore.translate("check_list")}: {this.state.checklist.c_name}</h1>
        <h2>Bitte bestätigen Sie folgende Punkte:</h2>
        <form onSubmit={this.submit}>
          <ul className="checklist_list">
            {items.map((item, i) => {
                 return (
                  <li key={i} className="checklist_point" id={"li_cp_" + item.cp_id} data-req={item.cp_required}>

                    {item.cp_required === "soft" &&
                      <input type="checkbox" id={item.cp_id} name={"CP[" + item.cp_id + "][id]"}
                        value={item.cp_id} onChange={(e) => this.onChange(e, item)} />
                    }

                    {item.cp_required === "hard" &&
                      <input type="checkbox" id={item.cp_id} name={"CP[" + item.cp_id + "][id]"}
                        value={item.cp_id}  onChange={(e) => this.onChange(e, item)} />
                    }

                    {item.cp_required === "no" &&
                      <input type="checkbox" id={item.cp_id} name={"CP[" + item.cp_id + "][id]"}
                        value={item.cp_id}  onChange={(e) => this.onChange(e, item)} />
                    }

                    {item.cp_required === "" &&
                      <input type="checkbox" id={item.cp_id} name={"CP[" + item.cp_id + "][id]"}
                        value={item.cp_id}  onChange={(e) => this.onChange(e, item)} />
                    }
                    <label>{item.cp_name}</label>
                    {item.cp_required === "soft" &&
                      <input className="optin_check" type="text" id={"text_" + item.cp_id} name={"CP[" + item.cp_id + "][id][text]"}
                        placeholder="Anmerkung" onChange={(e) => this.textChanged(e, item)} />
                    }
                  </li>
                )
              })}
          </ul>
          <MSButton type="submit" name="OK" />
        </form>
      </div>
    );
  }
}

export default Checklist;
