import languageDispatcher from "../Dispatcher";
import {EventEmitter} from "events";
import axios from 'axios';
import { properties } from '../properties.js';
import ls from 'local-storage'


class LanguageStore extends EventEmitter {

    constructor() {
        super();
        this.ls = require('local-storage');
        this.lang = ls('lang');

        if(!this.lang){
          this.lang = "DE";
        }

        this.localization = [];
        this.load = this.load.bind(this);
        this.load();
    }

    handleActions(action) {
      switch (action.type) {
          case "load_language": {
            this.lang = action.data;
            ls('lang', this.lang );
            this.load();
            this.emit("language_loaded");
            break;
          }
          default: {}
      }
    }

    load(){
      var url = properties.api_url + "/language/" + this.lang + "?SID=" + properties.key;
      axios.get(url)
        .then(res => {
          console.log("loading lang done")
          this.localization = res.data;
          this.emit("language_loaded");
        }).catch(function (error) {
          var error_str = "<div className='e'>" + error.message + " <br> "
           error_str += error.request.responseURL+ " </div>"
          window.$("#error_message").append(error_str);
          console.log(error);
        })
    }

    translate(key){
      if(this.localization){
        return this.localization[key]
      }
    }

    getLocalization() {
        return this.localization;
    }

    getLanguage() {
        return this.lang;
    }
}

const languageStore = new LanguageStore();
languageDispatcher.register(languageStore.handleActions.bind(languageStore));
export default languageStore;
